@@ -347,11 +347,11 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
             command = str(cmdline)
           else:
             if int(pcount) == 1:
-              command = str(show_template).format(str(par1))
+              command = str(show_template) + " {}".format(str(par1))
             elif int(pcount) == 2:
-              command = str(show_template).format(str(par1), str(par2))
+              command = str(show_template) + " {} {}".format(str(par1), str(par2))
             elif int(pcount) == 3:
-              command = str(show_template).format(str(par1), str(par2), str(par3))
+              command = str(show_template) + " {} {} {}".format(str(par1), str(par2), str(par3))
         #
         # Loop for a maximum of retries times to test value
         #
@@ -494,7 +494,7 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
       ddr_error_msg(f"ddr_nc_get_trigger Exception: {str(e)}")
       raise
 
-def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=False):
+def ddr_nc_get(device, access_type, xpath, leafs, return_response, debug_flag=False):
     """
      Sample xpath filter to reach interface in and out octets:
                 
@@ -514,7 +514,7 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
         :param device - list with device information for netconf conncetion
         :param access_type: 'loc', for local NETCONF connection, 'ssh' for ssh connection
         :param xpath - xpath for the filter required to select the leaf
-        :param leaf - list of XML tags for leafs which values should be returned, 'all' to return the complete response
+        :param leafs - list of XML tags for leafs which values should be returned, 'all' to return the complete response
         :param return_response - True if value should be returned by function call
         :param debug_flag: True to enable debug output for this call, False no debug output (default)
             
@@ -553,24 +553,36 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
     #
     # If leaf is set to 'all', return the complete NETCONF response
     #
-      if leaf == 'all':
+      if leafs == 'all':
         return get_result
-        
-      nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leaf)
-      ddr_debug_msg(debug_flag, f"ddr_nc_get nodes: {str(nodes)}")
+
+      values = []
+      if isinstance(leafs, list):
+        for leaf in leafs:
+          nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leaf)
+          ddr_debug_msg(debug_flag, f"ddr_nc_get leafs list nodes: {str(nodes)}")
     #
     # get all values for objects containing the leaf
     #
-      if nodes == []:
-        return "No matching data found"
-      for node in nodes:
-        value = node.firstChild.nodeValue
-      ddr_debug_msg(debug_flag, f"ddr_nc_get value: {str(value)}")
-                
-      if return_response:
-        return value
-      else:
-        return    
+          if nodes == []:
+            return "No matching data found"
+          for node in nodes:
+            value = node.firstChild.nodeValue
+            ddr_debug_msg(debug_flag, f"ddr_nc_get node value: {str(value)}")
+            values.append(value)
+            ddr_debug_msg(debug_flag, f"ddr_nc_get leafs values: {str(values)}")
+        return values
+        
+      else: # single leaf requested, not a list of leafs
+        nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leafs)
+        ddr_debug_msg(debug_flag, f"ddr_nc_get single leaf: {str(nodes)}")
+        if nodes == []:
+          return "No matching data found"
+        else:
+          for node in nodes:
+            value = node.firstChild.nodeValue
+            ddr_debug_msg(debug_flag, f"ddr_nc_get single leaf value: {str(value)}")
+            return value
 
     except Exception as e:
       netconf_connection.close_session()
@@ -1157,7 +1169,7 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
         ddr_error_msg("run_decode_btrace_log: Exception saving btrace log: {str(e)}")
         raise
 
-    return
+    return "success"
     
 def ddr_control_file(control_file, delay):
     """
